TelemetryErrorCode

Enum TelemetryErrorCode 

#[repr(i32)]
pub enum TelemetryErrorCode {
Show 17 variants GenericError = -2, InvalidType = -3, SizeMismatch = -4, SizeMismatchError = -5, EmptyEndpoints = -6, TimestampInvalid = -7, MissingPayload = -8, HandlerError = -9, BadArg = -10, PermissionDenied = -11, Pack = -12, Unpack = -13, Io = -14, InvalidUtf8 = -15, TypeMismatch = -16, InvalidLinkId = -17, PacketTooLarge = -18,
}
Numeric error codes used on the C/Python FFI boundary.

Negative values are used to avoid collisions with success codes and other positive return values (e.g. lengths).

Variants



GenericError = -2



InvalidType = -3



SizeMismatch = -4



SizeMismatchError = -5



EmptyEndpoints = -6



TimestampInvalid = -7



MissingPayload = -8



HandlerError = -9



BadArg = -10



PermissionDenied = -11



Pack = -12



Unpack = -13



Io = -14



InvalidUtf8 = -15



TypeMismatch = -16



InvalidLinkId = -17



PacketTooLarge = -18

Implementations

Source

impl TelemetryErrorCode

pub const MAX: i32

Maximum valid numeric error code value.

pub const MIN: i32

Minimum valid numeric error code value.

pub fn as_str(&self) -> &'static str

Human-readable string for logging / debugging.

Returns
  • Static string representation of the error code.
pub fn try_from_i32(x: i32) -> Option<Self>

Try to convert a raw i32 error code into a TelemetryErrorCode.

Returns None if the code is out of range or not recognized.

Arguments
  • x: Raw i32 error code to convert.
Returns
  • Some(TelemetryErrorCode) if valid, None if invalid.